==> ejc-proequipmentcorp-impl-3.0.0-20221027.025620-67-sources.jar: com/ejianc/business/proequipmentcorppur/settlement/bean/PurchaseSettlementDetailEntity.java <==
package com.ejianc.business.proequipmentcorppur.settlement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 设备采购-采购合同结算-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_settlement_detail")
public class PurchaseSettlementDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="settlement_id")
    private Long settlementId; // 结算主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="source_name")
    private String sourceName; // 来源类型名称(对账—100231)
    @TableField(value="source_code")
    private String sourceCode; // 来源编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="overage_settle_tax_mny")
    private BigDecimal overageSettleTaxMny; // 可结算金额
    @TableField(value="price")
    private BigDecimal price; // 结算单价(无税)
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 结算单价)
    @TableField(value="mny")
    private BigDecimal mny; // 结算金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 结算金额
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getSettlementId() {
        return settlementId;
    }

    public void setSettlementId(Long settlementId) {
        this.settlementId = settlementId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getOverageSettleTaxMny() {
        return overageSettleTaxMny;
    }

    public void setOverageSettleTaxMny(BigDecimal overageSettleTaxMny) {
        this.overageSettleTaxMny = overageSettleTaxMny;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20230323.082600-355-sources.jar: com/ejianc/business/proequipmentcorppur/settlement/bean/PurchaseSettlementDetailEntity.java <==
package com.ejianc.business.proequipmentcorppur.settlement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 设备采购-采购合同结算-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_purchase_settlement_detail")
public class PurchaseSettlementDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="settlement_id")
    private Long settlementId; // 结算主键ID
    @TableField(value="source_id")
    private Long sourceId; // 来源主键ID
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细主键ID
    @TableField(value="source_name")
    private String sourceName; // 来源类型名称(对账—100231)
    @TableField(value="source_code")
    private String sourceCode; // 来源编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="overage_settle_tax_mny")
    private BigDecimal overageSettleTaxMny; // 可结算金额
    @TableField(value="price")
    private BigDecimal price; // 结算单价(无税)
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 结算单价)
    @TableField(value="mny")
    private BigDecimal mny; // 结算金额(无税)
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 结算金额
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "equipment_factory_code")
    private String equipmentFactoryCode; //设备出厂编码
    
    

    public Long getSettlementId() {
        return settlementId;
    }

    public void setSettlementId(Long settlementId) {
        this.settlementId = settlementId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getOverageSettleTaxMny() {
        return overageSettleTaxMny;
    }

    public void setOverageSettleTaxMny(BigDecimal overageSettleTaxMny) {
        this.overageSettleTaxMny = overageSettleTaxMny;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getEquipmentFactoryCode() {
        return equipmentFactoryCode;
    }

    public void setEquipmentFactoryCode(String equipmentFactoryCode) {
        this.equipmentFactoryCode = equipmentFactoryCode;
    }
}
